.. ========
.. StratAge
.. ========

.. mdinclude:: ../readme.md

Contents
========

.. toctree::
   :maxdepth: 2

   Toy Example <toy-example>
   Module Reference <api/modules>
   License <license>
   Changelog <changelog>